@@ -1,12 +1,11 @@
 context("read-files")
 
-source("utils.R")
 
 test_succeeds("files can be read in parallel", {
 
-  mtcars_spec <- csv_record_spec("data/mtcars.csv")
+  mtcars_spec <- csv_record_spec(testing_data_filepath("mtcars.csv"))
 
-  dataset <- read_files("data/mtcars-*.csv", text_line_dataset, record_spec = mtcars_spec,
+  dataset <- read_files(testing_data_filepath("mtcars-*.csv"), text_line_dataset, record_spec = mtcars_spec,
                         parallel_files = 4, parallel_interleave = 1,
                         num_shards = 2, shard_index = 0) %>%
     dataset_batch(1000)
@@ -21,11 +20,3 @@ test_succeeds("files can be read in parallel", {
   }
 
 })
-
-
-
-
-
-
-
-
